---
title: '[공지] 토스페이먼츠 IE 브라우저 지원종료 안내'
category: 공지사항
tags:
  - 토스페이먼츠
  - 공지사항
pgCompanies:
  - 토스페이먼츠
datetime: 2024-03-18T10:02:37.923Z
---

토스페이먼츠 Internet Explorer 브라우저에 대한 지원을 종료할 예정인 것으로 공지되어 안내드립니다. \
관련하여 보다 자세한 내용은 아래 본문 혹은 토스페이먼츠를 통해 확인하여주시기 바랍니다.

<Callout title="[토스페이먼츠] Internet Explorer 브라우저 지원 종료 안내" content="
안녕하세요 토스페이먼츠입니다.
더 나은 결제 서비스를 지원하기 위해서, 최근 공식적으로 지원이 종료된 Internet Explorer 브라우저에 대한 결제 서비스 지원을 종료하고자 합니다. 

지원이 종료된 브라우저에서는 보안 및 성능의 결함이 발생할 수 있으며, 이에 대한 지원을 종료함으로써 고객사와 일반 사용자 분들에게 더 나은 결제 경험을 제공할 수 있습니다. 따라서 2023년 4월 3일 월요일 이후 로 토스페이먼츠의 결제 서비스는 Internet Explorer 브라우저의 공식적인 지원을 종료합니다.

**이후로 Internet Explorer 브라우저를 통한 결제가 불가능 할 수 있으며, Microsoft Edge, Google Chrome, Firefox, Safari 등의 대 브라우저를 이용해 주시도록 고객에게 안내 부탁 드립니다.**

Internet Explorer 만을 지원하고 있던 사이트의 경우, Microsoft Edge의 IE 모드를 통해서 동일한 사용자 경험을 지원할 수 있습니다.

관련하여 문제가 발생하거나 궁금하신 점이 있다면, 토스페이먼츠 고객센터 (1544-7772) 혹은 1:1 채팅 상담을 통해 문의를 부탁드립니다.

감사합니다.
토스페이먼츠 드림." />
